@@ -291,6 +291,9 @@ migrate_contacts (MigrationContext *context, EBook *old_book, EBook *new_book)
 
 		dialog_set_progress (context, (double)num_added / num_contacts);
 	}
+
+	g_list_foreach (contacts, (GFunc)g_object_unref, NULL);
+	g_list_free (contacts);
 }
 
 static void
@@ -742,9 +745,6 @@ migration_context_new (AddressbookComponent *component)
 
 	context->source_list = addressbook_component_peek_source_list (component);
 
-	/* initialize our dialog */
-	setup_progress_dialog (context);
-
 	context->component = component;
 
 	return context;
@@ -783,6 +783,8 @@ addressbook_migrate (AddressbookComponent *component, int major, int minor, int
 		    ||
 		    /* we're 0.x */
 		    (major == 0)) {
+			/* initialize our dialog */
+			setup_progress_dialog (context);
 
 			if (on_this_computer) {
 				migrate_local_folders (context, on_this_computer, personal_source);
