@@ -60,19 +60,10 @@ static gint e_minicard_drag_begin (EMinicard *minicard, GdkEvent *event);
 
 static GnomeCanvasGroupClass *parent_class = NULL;
 
-typedef struct _EMinicardField EMinicardField;
-
-struct _EMinicardField {
-	EContactField field;
-	GnomeCanvasItem *label;
-};
-
 #define d(x)
 
 #define LIST_ICON_FILENAME "contact-list-16.png"
 
-#define E_MINICARD_FIELD(field) ((EMinicardField *)(field))
-
 static void
 e_minicard_field_destroy(EMinicardField *field)
 {
@@ -225,6 +216,9 @@ e_minicard_class_init (EMinicardClass *klass)
 	item_class->event      = e_minicard_event;
 
 	klass->selected        = NULL;
+
+	/* init the accessibility support for e_minicard */
+	e_minicard_a11y_init();
 }
 
 static void
@@ -608,10 +602,7 @@ e_minicard_event (GnomeCanvasItem *item, GdkEvent *event)
 	case GDK_2BUTTON_PRESS:
 		if (event->button.button == 1 && E_IS_MINICARD_VIEW(item->parent)) {
 			if (e_minicard->editor) {
-				if (GPOINTER_TO_INT (e_contact_get (e_minicard->contact, E_CONTACT_IS_LIST)))
-					e_contact_list_editor_raise (E_CONTACT_LIST_EDITOR(e_minicard->editor));
-				else
-					e_contact_editor_raise(E_CONTACT_EDITOR(e_minicard->editor));
+				eab_editor_raise (e_minicard->editor);
 			} else {
 				EBook *book = NULL;
 				if (E_IS_MINICARD_VIEW(item->parent)) {
@@ -624,12 +615,12 @@ e_minicard_event (GnomeCanvasItem *item, GdkEvent *event)
 					if (e_contact_get (e_minicard->contact, E_CONTACT_IS_LIST)) {
 						EContactListEditor *editor = eab_show_contact_list_editor (book, e_minicard->contact,
 													   FALSE, e_minicard->editable);
-						e_minicard->editor = G_OBJECT (editor);
+						e_minicard->editor = EAB_EDITOR (editor);
 					}
 					else {
 						EContactEditor *editor = eab_show_contact_editor (book, e_minicard->contact,
 												  FALSE, e_minicard->editable);
-						e_minicard->editor = G_OBJECT (editor);
+						e_minicard->editor = EAB_EDITOR (editor);
 					}
 					g_object_ref (e_minicard->editor);
 
