@@ -32,7 +32,7 @@
 #include <bonobo/bonobo-exception.h>
 #include <libical/icalvcal.h>
 #include "e-pub-utils.h"
-#include "e-cal-view.h"
+#include "e-calendar-view.h"
 #include "calendar-config-keys.h"
 #include "calendar-config.h"
 #include "calendar-component.h"
@@ -76,8 +76,12 @@ struct _CalendarComponentPrivate {
 
 	GConfClient *gconf_client;
 	int gconf_notify_id;
+
 	ESourceList *source_list;
 	GSList *source_selection;
+
+	ESourceList *task_source_list;
+	GSList *task_source_selection;
 	
 	GnomeCalendar *calendar;
 	GtkWidget *source_selector;
@@ -140,14 +144,14 @@ update_uris_for_selection (CalendarComponent *calendar_component)
 		ESource *old_selected_source = l->data;
 
 		if (!is_in_selection (selection, old_selected_source))
-			gnome_calendar_remove_event_source (priv->calendar, old_selected_source);
+			gnome_calendar_remove_source (priv->calendar, E_CAL_SOURCE_TYPE_EVENT, old_selected_source);
 	}
 
 	for (l = selection; l; l = l->next) {
 		ESource *selected_source = l->data;
 		
-		gnome_calendar_add_event_source (priv->calendar, selected_source);
-		uids_selected = g_slist_append (uids_selected, (char *) e_source_peek_uid (selected_source));
+		if (gnome_calendar_add_source (priv->calendar, E_CAL_SOURCE_TYPE_EVENT, selected_source))
+			uids_selected = g_slist_append (uids_selected, (char *) e_source_peek_uid (selected_source));
 	}
 	
 	e_source_selector_free_selection (priv->source_selection);
@@ -171,7 +175,7 @@ update_uri_for_primary_selection (CalendarComponent *calendar_component)
 		return;
 
 	/* Set the default */
-	gnome_calendar_set_default_source (priv->calendar, source);
+	gnome_calendar_set_default_source (priv->calendar, E_CAL_SOURCE_TYPE_EVENT, source);
 
 	/* Make sure we are embedded first */
 	calendar_control_sensitize_calendar_commands (priv->view_control, priv->calendar, TRUE);
@@ -217,6 +221,43 @@ update_selection (CalendarComponent *calendar_component)
 	g_slist_free (uids_selected);
 }
 
+static void
+update_task_selection (CalendarComponent *calendar_component)
+{
+	CalendarComponentPrivate *priv;
+	GSList *uids_selected, *l;
+
+	priv = calendar_component->priv;
+
+	/* Get the selection in gconf */
+	uids_selected = calendar_config_get_tasks_selected ();
+
+	/* Remove any that aren't there any more */
+	for (l = priv->task_source_selection; l; l = l->next) {
+		char *uid = l->data;
+		ESource *source;
+
+		source = e_source_list_peek_source_by_uid (priv->task_source_list, uid);
+		if (!is_in_uids (uids_selected, source))
+			gnome_calendar_remove_source (priv->calendar, E_CAL_SOURCE_TYPE_TODO, source);
+		
+		g_free (uid);
+	}
+	g_slist_free (priv->task_source_selection);
+
+	/* Make sure the whole selection is there */
+	for (l = uids_selected; l; l = l->next) {
+		char *uid = l->data;
+		ESource *source;
+
+		source = e_source_list_peek_source_by_uid (priv->task_source_list, uid);
+		if (!gnome_calendar_add_source (priv->calendar, E_CAL_SOURCE_TYPE_TODO, source))
+			/* FIXME do something */;
+	}
+
+	priv->task_source_selection = uids_selected;
+}
+
 static void
 update_primary_selection (CalendarComponent *calendar_component)
 {
@@ -242,6 +283,25 @@ update_primary_selection (CalendarComponent *calendar_component)
 	}
 }
 
+static void
+update_primary_task_selection (CalendarComponent *calendar_component)
+{
+	CalendarComponentPrivate *priv;
+	ESource *source = NULL;
+	char *uid;
+
+	priv = calendar_component->priv;
+
+	uid = calendar_config_get_primary_tasks ();
+	if (uid) {
+		source = e_source_list_peek_source_by_uid (priv->source_list, uid);
+		g_free (uid);
+	}
+	
+	if (source)
+		gnome_calendar_set_default_source (priv->calendar, E_CAL_SOURCE_TYPE_TODO, source);
+}
+
 /* Callbacks.  */
 static void
 add_popup_menu_item (GtkMenu *menu, const char *label, const char *pixmap,
@@ -319,12 +379,14 @@ delete_calendar_cb (GtkWidget *widget, CalendarComponent *comp)
 		/* first, ask the backend to remove the calendar */
 		uri = e_source_get_uri (selected_source);
 		cal = e_cal_model_get_client_for_uri (gnome_calendar_get_calendar_model (priv->calendar), uri);
+		if (!cal)
+			cal = e_cal_new_from_uri (uri, E_CAL_SOURCE_TYPE_EVENT);
 		g_free (uri);
 		if (cal) {
 			if (e_cal_remove (cal, NULL)) {
 				if (e_source_selector_source_is_selected (E_SOURCE_SELECTOR (priv->source_selector),
 									  selected_source)) {
-					gnome_calendar_remove_event_source (priv->calendar, selected_source);
+					gnome_calendar_remove_source (priv->calendar, E_CAL_SOURCE_TYPE_EVENT, selected_source);
 					e_source_selector_unselect_source (E_SOURCE_SELECTOR (priv->source_selector),
 									   selected_source);
 				}
@@ -409,6 +471,19 @@ config_primary_selection_changed_cb (GConfClient *client, guint id, GConfEntry *
 	update_primary_selection (data);
 }
 
+static void
+config_tasks_selection_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
+{
+	update_task_selection (data);
+}
+
+
+static void
+config_primary_tasks_selection_changed_cb (GConfClient *client, guint id, GConfEntry *entry, gpointer data)
+{
+	update_primary_task_selection (data);
+}
+
 static gboolean
 init_calendar_publishing_cb (gpointer data)
 {	
@@ -552,7 +627,6 @@ selector_tree_drag_drop (GtkWidget *widget,
 		return FALSE;
 	}
 	
-	gtk_drag_get_data (widget, context, gdk_atom_intern (CALENDAR_TYPE, FALSE), time);
 	gtk_tree_path_free (path);
 	return TRUE;
 }
@@ -563,34 +637,37 @@ selector_tree_drag_motion (GtkWidget *widget,
 			   int x,
 			   int y)
 {
-	GtkTreePath *path;
+	GtkTreePath *path = NULL;
+	gpointer data = NULL;
 	GtkTreeViewDropPosition pos;
-	gpointer data;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
+	GdkDragAction action = GDK_ACTION_DEFAULT;
 	
 	if (!gtk_tree_view_get_dest_row_at_pos (GTK_TREE_VIEW (widget),
 						x, y, &path, &pos))
-		return FALSE;
+		goto finish;
 	
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (widget));
 	
-	if (!gtk_tree_model_get_iter (model, &iter, path)) {
-		gtk_tree_path_free (path);
-		return FALSE;
-	}
+	if (!gtk_tree_model_get_iter (model, &iter, path))
+		goto finish;
 	
 	gtk_tree_model_get (model, &iter, 0, &data, -1);
 
-	if (E_IS_SOURCE_GROUP (data) || e_source_get_readonly (data)) {
-		g_object_unref (data);
-		gtk_tree_path_free (path);
-		return FALSE;
-	}	
+	if (E_IS_SOURCE_GROUP (data) || e_source_get_readonly (data))
+		goto finish;
 	
 	gtk_tree_view_set_drag_dest_row(GTK_TREE_VIEW (widget), path, GTK_TREE_VIEW_DROP_INTO_OR_BEFORE);
-	
-	gtk_tree_path_free (path);
+	action = context->suggested_action;
+
+ finish:
+	if (path)
+		gtk_tree_path_free (path);
+	if (data)
+		g_object_unref (data);
+
+	gdk_drag_status (context, action, time);
 	return TRUE;
 }
 
@@ -648,7 +725,7 @@ update_objects (ECal *client, icalcomponent *icalcomp)
 	return TRUE;
 }
 
-static gboolean 
+static void
 selector_tree_drag_data_received (GtkWidget *widget, 
 				  GdkDragContext *context, 
 				  gint x, 
@@ -658,70 +735,63 @@ selector_tree_drag_data_received (GtkWidget *widget,
 				  guint time,
 				  gpointer user_data)
 {
-	GtkTreePath *path;
+	GtkTreePath *path = NULL;
 	GtkTreeViewDropPosition pos;
-	gpointer source;
+	gpointer source = NULL;
 	GtkTreeModel *model;
 	GtkTreeIter iter;
-	gboolean ret = FALSE;
+	gboolean success = FALSE;
+	icalcomponent *icalcomp = NULL;
+	ECal *client = NULL;
 
 	if (!gtk_tree_view_get_dest_row_at_pos (GTK_TREE_VIEW (widget),
 						x, y, &path, &pos))
-		return FALSE;
+		goto finish;
 	
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (widget));
 	
-	if (!gtk_tree_model_get_iter (model, &iter, path)) {
-		gtk_tree_path_free (path);
-		return FALSE;
-	}
+	if (!gtk_tree_model_get_iter (model, &iter, path))
+		goto finish;
+       
 	
 	gtk_tree_model_get (model, &iter, 0, &source, -1);
 
-	if (E_IS_SOURCE_GROUP (source) || e_source_get_readonly (source)) {
-		g_object_unref (source);
-		gtk_tree_path_free (path);
-		return FALSE;
-	}	
-	
-	
-	if ((data->length >= 0) && (data->format == 8)) {
-		gtk_drag_finish (context, FALSE, TRUE, time);
-	} else {
-		gtk_drag_finish (context, FALSE, FALSE, time);
-	}
-	gtk_tree_path_free (path);
+	if (E_IS_SOURCE_GROUP (source) || e_source_get_readonly (source))
+		goto finish;
 
+	icalcomp = icalparser_parse_string (data->data);
 	
-	//e_source_selector_set_primary_selection (E_SOURCE_SELECTOR (widget), source);
-	{
-		icalcomponent *ical_comp = NULL;
-		icalvcal_defaults defaults = { 0 };
-		VObject *vcal;
-		ECal *client = NULL;
-			
-			
-		vcal = Parse_MIME (data->data, data->length);
-		if (vcal) {
-			ical_comp = icalvcal_convert_with_defaults (vcal, &defaults);
-			cleanVObject (vcal);
-			
-			if (ical_comp)
-				client = auth_new_cal_from_source (source, 
-								   E_CAL_SOURCE_TYPE_EVENT);
-			
-			if (client) {
-				if (e_cal_open (client, TRUE, NULL)) {
-					/* FIXME should the drag status be set here? */
-					update_objects (client, ical_comp);
-				}
+	if (icalcomp) {
+		char * uid;
 
-				g_object_unref (client);
-			}
+		/* FIXME deal with GDK_ACTION_ASK */
+		if (context->action == GDK_ACTION_COPY) {
+			uid = e_cal_component_gen_uid ();
+			icalcomponent_set_uid (icalcomp, uid);
 		}
+
+		client = auth_new_cal_from_source (source, 
+						   E_CAL_SOURCE_TYPE_EVENT);
+		
+		if (client) {
+			if (e_cal_open (client, TRUE, NULL)) {
+				success = TRUE;
+				update_objects (client, icalcomp);
+			}
+			
+			g_object_unref (client);
+		}
+		
+		icalcomponent_free (icalcomp);
 	}
 
-	return ret;
+ finish:
+	if (source)
+		g_object_unref (source);
+	if (path)
+		gtk_tree_path_free (path);
+
+	gtk_drag_finish (context, success, context->action == GDK_ACTION_MOVE, time);
 }	
 
 static void
@@ -810,8 +880,10 @@ impl_createControls (PortableServer_Servant servant,
 	/* Load the selection from the last run */
 	update_selection (calendar_component);	
 	update_primary_selection (calendar_component);
-
-	/* If it gets fiddled with update */
+	update_task_selection (calendar_component);
+	update_primary_task_selection (calendar_component);
+	
+	/* If the selection changes elsewhere, update it */
 	not = calendar_config_add_notification_calendars_selected (config_selection_changed_cb, 
 								   calendar_component);
 	priv->notifications = g_list_prepend (priv->notifications, GUINT_TO_POINTER (not));
@@ -820,6 +892,14 @@ impl_createControls (PortableServer_Servant servant,
 								 calendar_component);
 	priv->notifications = g_list_prepend (priv->notifications, GUINT_TO_POINTER (not));
 
+	not = calendar_config_add_notification_tasks_selected (config_tasks_selection_changed_cb, 
+							       calendar_component);
+	priv->notifications = g_list_prepend (priv->notifications, GUINT_TO_POINTER (not));
+
+	not = calendar_config_add_notification_primary_tasks (config_primary_tasks_selection_changed_cb, 
+							      calendar_component);
+	priv->notifications = g_list_prepend (priv->notifications, GUINT_TO_POINTER (not));
+
 	/* Return the controls */
 	*corba_sidebar_control = CORBA_Object_duplicate (BONOBO_OBJREF (sidebar_control), ev);
 	*corba_view_control = CORBA_Object_duplicate (BONOBO_OBJREF (priv->view_control), ev);
@@ -1046,8 +1126,11 @@ calendar_component_init (CalendarComponent *component)
 	 * calendar_component_peek_gconf_client().  */
 	priv->gconf_client = gconf_client_get_default ();
 
+	/* FIXME Use ecal convenience functions */
 	priv->source_list = e_source_list_new_for_gconf (priv->gconf_client,
 							 "/apps/evolution/calendar/sources");
+	priv->task_source_list = e_source_list_new_for_gconf (priv->gconf_client,
+							 "/apps/evolution/tasks/sources");
 
 	priv->activity_handler = e_activity_handler_new ();
 
@@ -1098,7 +1181,7 @@ calendar_component_peek_source_list (CalendarComponent *component)
 ESourceSelector *
 calendar_component_peek_source_selector (CalendarComponent *component)
 {
-	return component->priv->source_selector;
+	return E_SOURCE_SELECTOR (component->priv->source_selector);
 }
 
 EActivityHandler *
