@@ -80,6 +80,7 @@ guint	  calendar_config_add_notification_primary_calendar (GConfClientNotifyFunc
 
 /* The current timezone, e.g. "Europe/London". */
 gchar*	  calendar_config_get_timezone		(void);
+icaltimezone *calendar_config_get_icaltimezone (void);
 void	  calendar_config_set_timezone		(gchar	     *timezone);
 guint calendar_config_add_notification_timezone (GConfClientNotifyFunc func, gpointer data);
 
@@ -202,6 +203,9 @@ void     calendar_config_set_default_reminder_interval (int interval);
 CalUnits calendar_config_get_default_reminder_units (void);
 void     calendar_config_set_default_reminder_units (CalUnits units);
 
+/* Free/Busy Settings */
+GSList * calendar_config_get_free_busy (void);
+void calendar_config_set_free_busy (GSList * url_list);
 
 /* Convenience functions to configure common properties of ECalendar,
    EDateEdit & ECalendarTable widgets, and the ECellDateEdit ETable cell. */
