@@ -539,3 +539,40 @@ e_calendar_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
+/* NONE:LONG,LONG (./e-calendar-marshal.list:16) */
+void
+e_calendar_marshal_VOID__LONG_LONG (GClosure     *closure,
+                                    GValue       *return_value,
+                                    guint         n_param_values,
+                                    const GValue *param_values,
+                                    gpointer      invocation_hint,
+                                    gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__LONG_LONG) (gpointer     data1,
+                                                glong        arg_1,
+                                                glong        arg_2,
+                                                gpointer     data2);
+  register GMarshalFunc_VOID__LONG_LONG callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__LONG_LONG) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_long (param_values + 1),
+            g_marshal_value_peek_long (param_values + 2),
+            data2);
+}
+
