@@ -382,7 +382,7 @@ search_bar_sexp_changed_cb (CalSearchBar *cal_search, const char *sexp, gpointer
 	priv = tasks->priv;
 
 	model = e_calendar_table_get_model (E_CALENDAR_TABLE (priv->tasks_view));
-	e_cal_model_set_query (model, sexp);
+	e_cal_model_set_search_query (model, sexp);
 }
 
 /* Callback used when the selected category in the search bar changes */
@@ -642,7 +642,8 @@ static void
 e_tasks_init (ETasks *tasks)
 {
 	ETasksPrivate *priv;
-
+	ECalModel *model;
+	
 	priv = g_new0 (ETasksPrivate, 1);
 	tasks->priv = priv;
 
@@ -654,6 +655,9 @@ e_tasks_init (ETasks *tasks)
 	priv->view_instance = NULL;
 	priv->view_menus = NULL;
 	priv->current_uid = NULL;
+
+	model = e_calendar_table_get_model (E_CALENDAR_TABLE (priv->tasks_view));
+	e_cal_model_set_search_query (model, "#t");
 }
 
 /* Callback used when the set of categories changes in the calendar client */
@@ -1033,6 +1037,7 @@ e_tasks_delete_selected (ETasks *tasks)
 	set_status_message (tasks, _("Deleting selected objects..."));
 	e_calendar_table_delete_selected (cal_table);
 	set_status_message (tasks, NULL);
+	gtk_html_load_empty (GTK_HTML (priv->html));
 }
 
 /**
@@ -1156,7 +1161,7 @@ e_tasks_setup_view_menus (ETasks *tasks, BonoboUIComponent *uic)
 		gal_view_collection_load (collection);
 	}
 
-	priv->view_instance = gal_view_instance_new (collection, e_cal_get_uri (e_tasks_get_default_client (tasks)));
+	priv->view_instance = gal_view_instance_new (collection, NULL);
 
 	priv->view_menus = gal_view_menus_new (priv->view_instance);
 	gal_view_menus_apply (priv->view_menus, uic, NULL);
