@@ -434,13 +434,15 @@ cobject_state_read(CamelObject *obj, FILE *fp)
 		CamelArgV *argv;
 
 		if (camel_file_util_decode_uint32(fp, &count) == -1
-			|| count == 0) {
+			|| count == 0 || count > 1024) {
 			/* maybe it was just version 0 afterall */
 			return 0;
 		}
-
+		
 		/* we batch up the properties and set them in one go */
-		argv = g_malloc(sizeof(*argv) + (count - CAMEL_ARGV_MAX) * sizeof(argv->argv[0]));
+		if (!(argv = g_try_malloc (sizeof (*argv) + (count - CAMEL_ARGV_MAX) * sizeof (argv->argv[0]))))
+			return -1;
+		
 		argv->argc = 0;
 		for (i=0;i<count;i++) {
 			if (camel_file_util_decode_uint32(fp, &argv->argv[argv->argc].tag) == -1)
@@ -1809,6 +1811,38 @@ camel_object_bag_get(CamelObjectBag *bag, const void *key)
 	return o;
 }
 
+/**
+ * camel_object_bag_peek:
+ * @bag: 
+ * @key: 
+ * 
+ * Lookup the object @key in @bag, ignoring any reservations.  If it
+ * isn't committed, then it isn't considered.  This should only be
+ * used where reliable transactional-based state is not required.
+ * 
+ * Unlike other 'peek' operations, the object is still reffed if
+ * found.
+ *
+ * Return value: A referenced object, or NULL if @key is not
+ * present in the bag.
+ **/
+void *
+camel_object_bag_peek(CamelObjectBag *bag, const void *key)
+{
+	CamelObject *o;
+
+	E_LOCK(type_lock);
+
+	o = g_hash_table_lookup(bag->object_table, key);
+	if (o) {
+		/* we use the same lock as the refcount */
+		o->ref_count++;
+	}
+	E_UNLOCK(type_lock);
+
+	return o;
+}
+
 /**
  * camel_object_bag_reserve:
  * @bag: 
