@@ -31,6 +31,8 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 
+#include "camel-debug.h"
+
 #include "camel-session.h"
 #include "camel-store.h"
 #include "camel-folder.h"
@@ -234,8 +236,6 @@ camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flag
 	if (!(flags & CAMEL_STORE_FOLDER_CREATE))
 		flags &= ~CAMEL_STORE_FOLDER_EXCL;
 	
-	CAMEL_STORE_LOCK(store, folder_lock);
-	
 	if (store->folders) {
 		/* Try cache first. */
 		folder = camel_object_bag_reserve(store->folders, folder_name);
@@ -281,8 +281,6 @@ camel_store_get_folder (CamelStore *store, const char *folder_name, guint32 flag
 		}
 	}
 
-	CAMEL_STORE_UNLOCK(store, folder_lock);
-
 	return folder;
 }
 
@@ -687,14 +685,14 @@ add_special_info (CamelStore *store, CamelFolderInfo *info, const char *name, co
 	g_return_if_fail (info != NULL);
 	
 	parent = NULL;
-	for (fi = info; fi; fi = fi->sibling) {
+	for (fi = info; fi; fi = fi->next) {
 		if (!strcmp (fi->name, name))
 			break;
 		parent = fi;
 	}
 	
 	/* create our vTrash/vJunk URL */
-	url = camel_url_new (info->url, NULL);
+	url = camel_url_new (info->uri, NULL);
 	if (((CamelService *) store)->provider->url_flags & CAMEL_URL_FRAGMENT_IS_PATH) {
 		camel_url_set_fragment (url, name);
 	} else {
@@ -711,7 +709,7 @@ add_special_info (CamelStore *store, CamelFolderInfo *info, const char *name, co
 		vinfo = fi;
 		g_free (vinfo->full_name);
 		g_free (vinfo->name);
-		g_free (vinfo->url);
+		g_free (vinfo->uri);
 		g_free (vinfo->path);
 	} else {
 		/* There wasn't a Trash/Junk folder so create a new folder entry */
@@ -722,20 +720,38 @@ add_special_info (CamelStore *store, CamelFolderInfo *info, const char *name, co
 		vinfo->flags |= CAMEL_FOLDER_NOINFERIORS | CAMEL_FOLDER_SUBSCRIBED;
 		
 		/* link it into the right spot */
-		vinfo->sibling = parent->sibling;
-		parent->sibling = vinfo;
+		vinfo->next = parent->next;
+		parent->next = vinfo;
 	}
 	
 	/* Fill in the new fields */
-	vinfo->flags |= CAMEL_FOLDER_VIRTUAL;
+	vinfo->flags |= CAMEL_FOLDER_VIRTUAL|CAMEL_FOLDER_SYSTEM|CAMEL_FOLDER_VTRASH;
 	vinfo->full_name = g_strdup (full_name);
 	vinfo->name = g_strdup (vinfo->full_name);
-	vinfo->url = uri;
+	vinfo->uri = uri;
 	if (!unread_count)
-		vinfo->unread_message_count = -1;
+		vinfo->unread = -1;
 	vinfo->path = g_strdup_printf ("/%s", vinfo->name);
 }
 
+static void
+dump_fi(CamelFolderInfo *fi, int depth)
+{
+	char *s;
+
+	s = g_alloca(depth+1);
+	memset(s, ' ', depth);
+	s[depth] = 0;
+
+	while (fi) {
+		printf("%suri: %s\n", s, fi->uri);
+		printf("%sfull_name: %s\n", s, fi->full_name);
+		printf("%sflags: %08x\n", s, fi->flags);
+		dump_fi(fi->child, depth+2);
+		fi = fi->next;
+	}
+}
+
 /**
  * camel_store_get_folder_info:
  * @store: a CamelStore
@@ -770,21 +786,26 @@ camel_store_get_folder_info(CamelStore *store, const char *top, guint32 flags, C
 			      !(flags & CAMEL_STORE_FOLDER_INFO_SUBSCRIBED),
 			      NULL);
 
-	CAMEL_STORE_LOCK(store, folder_lock);
 	info = CS_CLASS (store)->get_folder_info (store, top, flags, ex);
-	CAMEL_STORE_UNLOCK(store, folder_lock);
 	
 	if (info && (top == NULL || *top == '\0') && (flags & CAMEL_STORE_FOLDER_INFO_NO_VIRTUAL) == 0) {
-		if (info->url && (store->flags & CAMEL_STORE_VTRASH))
+		if (info->uri && (store->flags & CAMEL_STORE_VTRASH))
 			add_special_info (store, info, CAMEL_VTRASH_NAME, _("Trash"), FALSE);
-		if (info->url && (store->flags & CAMEL_STORE_VJUNK))
+		if (info->uri && (store->flags & CAMEL_STORE_VJUNK))
 			add_special_info (store, info, CAMEL_VJUNK_NAME, _("Junk"), TRUE);
 	}
+
+	if (camel_debug_start("store:folder_info")) {
+		char *url = camel_url_to_string(((CamelService *)store)->url, CAMEL_URL_HIDE_ALL);
+		printf("Get folder info(%p:%s, '%s') =\n", store, url, top?top:"<null>");
+		g_free(url);
+		dump_fi(info, 2);
+		camel_debug_end();
+	}
 	
 	return info;
 }
 
-
 static void
 free_folder_info (CamelStore *store, CamelFolderInfo *fi)
 {
@@ -844,12 +865,12 @@ void
 camel_folder_info_free (CamelFolderInfo *fi)
 {
 	if (fi) {
-		camel_folder_info_free (fi->sibling);
+		camel_folder_info_free (fi->next);
 		camel_folder_info_free (fi->child);
 		g_free (fi->name);
 		g_free (fi->full_name);
 		g_free (fi->path);
-		g_free (fi->url);
+		g_free (fi->uri);
 		g_free (fi);
 	}
 }
@@ -983,7 +1004,7 @@ camel_folder_info_build (GPtrArray *folders, const char *namespace,
 					pfi->name = g_strdup (pname);
 
 				/* FIXME: url's with fragments should have the fragment truncated, not path */
-				url = camel_url_new (fi->url, NULL);
+				url = camel_url_new (fi->uri, NULL);
 				sep = strrchr (url->path, separator);
 				if (sep)
 					*sep = '\0';
@@ -994,7 +1015,7 @@ camel_folder_info_build (GPtrArray *folders, const char *namespace,
 
 				/* since this is a "fake" folder node, it is not selectable */
 				camel_url_set_param (url, "noselect", "yes");
-				pfi->url = camel_url_to_string (url, 0);
+				pfi->uri = camel_url_to_string (url, 0);
 				camel_url_free (url);
 
 				g_hash_table_insert (hash, pname, pfi);
@@ -1004,9 +1025,9 @@ camel_folder_info_build (GPtrArray *folders, const char *namespace,
 			if (tail == NULL) {
 				pfi->child = fi;
 			} else {
-				while (tail->sibling)
-					tail = tail->sibling;
-				tail->sibling = fi;
+				while (tail->next)
+					tail = tail->next;
+				tail->next = fi;
 			}
 			fi->parent = pfi;
 		} else if (!top)
@@ -1025,7 +1046,7 @@ camel_folder_info_build (GPtrArray *folders, const char *namespace,
 			tail = fi;
 			top = fi;
 		} else {
-			tail->sibling = fi;
+			tail->next = fi;
 			tail = fi;
 		}
 	}
@@ -1039,17 +1060,17 @@ static CamelFolderInfo *folder_info_clone_rec(CamelFolderInfo *fi, CamelFolderIn
 
 	info = g_malloc(sizeof(*info));
 	info->parent = parent;
-	info->url = g_strdup(fi->url);
+	info->uri = g_strdup(fi->uri);
 	info->name = g_strdup(fi->name);
 	info->full_name = g_strdup(fi->full_name);
 	info->path = g_strdup(fi->path);
-	info->unread_message_count = fi->unread_message_count;
+	info->unread = fi->unread;
 	info->flags = fi->flags;
 	
-	if (fi->sibling)
-		info->sibling = folder_info_clone_rec(fi->sibling, parent);
+	if (fi->next)
+		info->next = folder_info_clone_rec(fi->next, parent);
 	else
-		info->sibling = NULL;
+		info->next = NULL;
 
 	if (fi->child)
 		info->child = folder_info_clone_rec(fi->child, info);
