@@ -40,9 +40,14 @@
 #include <gtk/gtkstock.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtkarrow.h>
-
+#include <gtk/gtklabel.h>
+#include <gtk/gtkentry.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtktable.h>
 #include <gtk/gtkmenu.h>
 #include <gtk/gtkmenuitem.h>
+#include <gtk/gtkmain.h>
+#include <gtk/gtkdnd.h>
 
 #include <glade/glade.h>
 
@@ -66,6 +71,8 @@
 #include <camel/camel-internet-address.h>
 #include <camel/camel-mime-message.h>
 #include <camel/camel-cipher-context.h>
+#include <camel/camel-folder.h>
+#include <camel/camel-string-utils.h>
 
 /* should this be in e-util rather than gal? */
 #include <gal/util/e-util.h>
@@ -87,7 +94,6 @@
 #include "em-icon-stream.h"
 #include "em-utils.h"
 #include "em-popup.h"
-#include "em-icon-stream.h"
 
 #define d(x)
 
@@ -305,7 +311,7 @@ efhd_class_init(GObjectClass *klass)
 			     G_SIGNAL_RUN_LAST,
 			     G_STRUCT_OFFSET(EMFormatHTMLDisplayClass, on_url),
 			     NULL, NULL,
-			     gtk_marshal_VOID__STRING,
+			     g_cclosure_marshal_VOID__STRING,
 			     G_TYPE_NONE, 1,
 			     G_TYPE_STRING);
 
@@ -458,6 +464,7 @@ efhd_search_response(GtkWidget *w, int button, EMFormatHTMLDisplay *efhd)
 		g_free(p->search_text);
 		p->search_text = NULL;
 		gtk_widget_destroy((GtkWidget *)p->search_dialog);
+		e_searching_tokenizer_reset (efhd->search_tok);
 		p->search_dialog = NULL;
 	}
 }
@@ -517,7 +524,6 @@ em_format_html_display_search(EMFormatHTMLDisplay *efhd)
 	g_signal_connect(p->search_entry, "activate", G_CALLBACK(efhd_search_entry_activate), efhd);
 	g_signal_connect(p->search_case_check, "toggled", G_CALLBACK(efhd_search_case_toggled), efhd);
 	g_signal_connect(p->search_dialog, "response", G_CALLBACK(efhd_search_response), efhd);
-	e_dialog_set_transient_for((GtkWindow *)p->search_dialog, (GtkWidget *)efhd);
 	gtk_widget_show((GtkWidget *)p->search_dialog);
 }
 
@@ -636,8 +642,8 @@ efhd_complete(EMFormat *emf)
 static const struct {
 	const char *icon, *shortdesc, *description;
 } smime_sign_table[4] = {
-	{ NULL, N_("Unsigned"), N_("This message is not signed.  There is no guarantee the sender of the message is authentic.") },
-	{ "pgp-signature-ok.png",N_("Valid signature"), N_("This message is signed and is valid, the sender of this message is very likely who they claim to be.") },
+	{ NULL, N_("Unsigned"), N_("This message is not signed. There is no guarantee that this message is authentic.") },
+	{ "pgp-signature-ok.png", N_("Valid signature"), N_("This message is signed and is valid meaning that it is very likely that this message is authentic.") },
 	{ "pgp-signature-bad.png", N_("Invalid signature"), N_("The signature of this message cannot be verified, it may have been altered in transit.") },
 	{ "pgp-signature-nokey.png", N_("Valid signature, cannot verify sender"), N_("This message is signed with a valid signature, but the sender of the message cannot be verified.") },
 };
@@ -764,7 +770,7 @@ efhd_xpkcs7mime_validity_clicked(GtkWidget *button, EMFormatHTMLPObject *pobject
 	po->widget = glade_xml_get_widget(xml, "message_security_dialog");
 
 	vbox = glade_xml_get_widget(xml, "signature_vbox");
-	w = gtk_label_new(_(smime_sign_table[po->valid->sign.status].description));
+	w = gtk_label_new (_(smime_sign_table[po->valid->sign.status].description));
 	gtk_misc_set_alignment((GtkMisc *)w, 0.0, 0.5);
 	gtk_label_set_line_wrap((GtkLabel *)w, TRUE);
 	gtk_box_pack_start((GtkBox *)vbox, w, TRUE, TRUE, 6);
@@ -813,11 +819,8 @@ efhd_xpkcs7mime_button(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObje
 	const char *name;
 
 	/* FIXME: need to have it based on encryption and signing too */
-	if (po->valid->sign.status == CAMEL_CIPHER_VALIDITY_SIGN_GOOD)
-		name = "pgp-signature-ok.png";
-	else
-		name = "pgp-signature-bad.png";
-
+	name = smime_sign_table[po->valid->sign.status].icon;
+	
 	file = g_build_filename(EVOLUTION_ICONSDIR, name, NULL);
 	pixbuf = gdk_pixbuf_new_from_file(file, NULL);
 	g_free(file);
@@ -1089,11 +1092,15 @@ efhd_attachment_popup(GtkWidget *w, GdkEventButton *event, struct _attach_puri *
 	target->widget = w;
 
 	/* add our local menus */
-	efhd_menu_items[0].activate_data = info;
-	menus = g_slist_prepend(menus, &efhd_menu_items[0]);
-	item = &efhd_menu_items[info->shown?2:1];
-	item->activate_data = info;
-	menus = g_slist_prepend(menus, item);
+	if (info->handle) {
+		/* show/hide menus, only if we have an inline handler */
+		efhd_menu_items[0].activate_data = info;
+		menus = g_slist_prepend(menus, &efhd_menu_items[0]);
+		item = &efhd_menu_items[info->shown?2:1];
+		item->activate_data = info;
+		menus = g_slist_prepend(menus, item);
+	}
+
 	em_popup_add_items(emp, menus, (GDestroyNotify)g_slist_free);
 
 	menu = em_popup_create_menu_once(emp, target, target->mask, target->mask);
@@ -1215,8 +1222,10 @@ efhd_attachment_button(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObje
 
 	if (info->handle)
 		g_signal_connect(button, "clicked", G_CALLBACK(efhd_attachment_show), info);
-	else
+	else {
+		gtk_widget_set_sensitive(button, FALSE);
 		GTK_WIDGET_UNSET_FLAGS(button, GTK_CAN_FOCUS);
+	}
 
 	hbox = gtk_hbox_new(FALSE, 2);
 	info->forward = gtk_image_new_from_stock(GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON);
@@ -1258,12 +1267,15 @@ efhd_attachment_button(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObje
 			em_format_html_job_queue(efh, job);
 		}
 	} else {
-		GdkPixbuf *pixbuf = e_icon_for_mime_type(simple_type, 24);
-		GdkPixbuf *mini = gdk_pixbuf_scale_simple(pixbuf, 24, 24, GDK_INTERP_BILINEAR);
-
-		gtk_image_set_from_pixbuf((GtkImage *)w, mini);
-		g_object_unref(mini);
-		g_object_unref(pixbuf);
+		GdkPixbuf *pixbuf, *mini;
+		
+		if ((pixbuf = e_icon_for_mime_type (simple_type, 24))) {
+			if ((mini = gdk_pixbuf_scale_simple (pixbuf, 24, 24, GDK_INTERP_BILINEAR))) {
+				gtk_image_set_from_pixbuf ((GtkImage *) w, mini);
+				g_object_unref (mini);
+			}
+			g_object_unref (pixbuf);
+		}
 	}
 
 	drag_types[0].target = simple_type;
@@ -1274,7 +1286,7 @@ efhd_attachment_button(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObje
 
 	button = gtk_button_new();
 	/*GTK_WIDGET_UNSET_FLAGS(button, GTK_CAN_FOCUS);*/
-	gtk_container_add((GtkContainer *)button, gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_ETCHED_IN));
+	gtk_container_add((GtkContainer *)button, gtk_arrow_new(GTK_ARROW_DOWN, GTK_SHADOW_NONE));
 	g_signal_connect(button, "button_press_event", G_CALLBACK(efhd_attachment_popup), info);
 	g_signal_connect(button, "popup_menu", G_CALLBACK(efhd_attachment_popup_menu), info);
 	g_signal_connect(button, "clicked", G_CALLBACK(efhd_attachment_popup_menu), info);
@@ -1347,7 +1359,7 @@ efhd_bonobo_object(EMFormatHTML *efh, GtkHTMLEmbedded *eb, EMFormatHTMLPObject *
 		 */
 		const CamelInternetAddress *from;
 		char *from_address;
-				
+		
 		from = camel_mime_message_get_from((CamelMimeMessage *)((EMFormat *)efh)->message);
 		from_address = camel_address_encode((CamelAddress *)from);
 		bonobo_property_bag_client_set_value_string(prop_bag, "from_address", from_address, &ev);
@@ -1465,7 +1477,7 @@ efhd_format_attachment(EMFormat *emf, CamelStream *stream, CamelMimePart *part,
 	info->snoop_mime_type = emf->snoop_mime_type;
 
 	camel_stream_write_string(stream,
-				  "<table height=6><tr><td><a></a></td></tr></table>\n"
+				  EM_FORMAT_HTML_VPAD
 				  "<table cellspacing=0 cellpadding=0><tr><td>"
 				  "<table width=10 cellspacing=0 cellpadding=0>"
 				  "<tr><td></td></tr></table></td>");
@@ -1486,7 +1498,7 @@ efhd_format_attachment(EMFormat *emf, CamelStream *stream, CamelMimePart *part,
 
 	camel_stream_write_string(stream,
 				  "</font></td></tr><tr></table>\n"
-				  "<table height=6><tr><td><a></a></td></tr></table>\n");
+				  EM_FORMAT_HTML_VPAD);
 
 	if (handle) {
 		if (info->shown)
