@@ -78,6 +78,7 @@ struct _EMMailerPrefs {
 	
 	/* Deleting Mail */
 	GtkToggleButton *empty_trash;
+	GtkOptionMenu *empty_trash_days;
 	GtkToggleButton *confirm_expunge;
 	
 	/* New Mail Notification */
@@ -116,7 +117,6 @@ struct _EMMailerPrefs {
 
 	/* Junk prefs */
 	GtkToggleButton *check_incoming;
-	GtkToggleButton *check_incoming_imap;
 	GtkToggleButton *sa_local_tests_only;
 	GtkToggleButton *sa_use_daemon;
 };
