@@ -37,8 +37,8 @@
 #include <camel/camel-operation.h>
 #include <camel/camel-vtrash-folder.h>
 #include <camel/camel-vee-store.h>
-#include "mail.h"
 #include "mail-component.h"
+#include "mail-config.h"
 #include "mail-tools.h"
 #include "mail-ops.h"
 #include "mail-vfolder.h"
@@ -207,13 +207,19 @@ mail_filter_folder (CamelFolder *source_folder, GPtrArray *uids,
 	e_thread_put (mail_thread_new, (EMsg *)m);
 }
 
-/* convenience function for it */
+/* convenience functions for it */
 void
 mail_filter_on_demand (CamelFolder *folder, GPtrArray *uids)
 {
 	mail_filter_folder (folder, uids, FILTER_SOURCE_DEMAND, FALSE, NULL);
 }
 
+void
+mail_filter_junk (CamelFolder *folder, GPtrArray *uids)
+{
+	mail_filter_folder (folder, uids, FILTER_SOURCE_JUNKTEST, FALSE, NULL);
+}
+
 /* ********************************************************************** */
 
 /* Temporary workaround for various issues. Gone before 0.11 */
@@ -579,90 +585,6 @@ mail_send_message (CamelMimeMessage *message, const char *destination,
 		g_string_free (err, TRUE);
 }
 
-/* ********************************************************************** */
-
-struct _send_mail_msg {
-	struct _mail_msg msg;
-
-	CamelFilterDriver *driver;
-	char *destination;
-	CamelMimeMessage *message;
-	
-	void (*done)(char *uri, CamelMimeMessage *message, gboolean sent, void *data);
-	void *data;
-};
-
-static char *
-send_mail_desc (struct _mail_msg *mm, int done)
-{
-	struct _send_mail_msg *m = (struct _send_mail_msg *)mm;
-	const char *subject;
-	
-	subject = camel_mime_message_get_subject (m->message);
-	
-	if (subject)
-		return g_strdup_printf (_("Sending \"%s\""), subject);
-	else
-		return g_strdup (_("Sending message"));
-}
-
-static void
-send_mail_send (struct _mail_msg *mm)
-{
-	struct _send_mail_msg *m = (struct _send_mail_msg *)mm;
-	
-	mail_send_message (m->message, m->destination, m->driver, &mm->ex);
-}
-
-static void
-send_mail_sent (struct _mail_msg *mm)
-{
-	struct _send_mail_msg *m = (struct _send_mail_msg *)mm;
-	
-	if (m->done)
-		m->done (m->destination, m->message, !camel_exception_is_set (&mm->ex), m->data);
-}
-
-static void
-send_mail_free (struct _mail_msg *mm)
-{
-	struct _send_mail_msg *m = (struct _send_mail_msg *)mm;
-	
-	camel_object_unref (m->driver);
-	camel_object_unref (m->message);
-	g_free (m->destination);
-}
-
-static struct _mail_msg_op send_mail_op = {
-	send_mail_desc,
-	send_mail_send,
-	send_mail_sent,
-	send_mail_free,
-};
-
-int
-mail_send_mail (const char *uri, CamelMimeMessage *message,
-		void (*done) (char *uri, CamelMimeMessage *message, gboolean sent, void *data),
-		void *data)
-{
-	struct _send_mail_msg *m;
-	int id;
-	
-	m = mail_msg_new (&send_mail_op, NULL, sizeof (*m));
-	m->destination = g_strdup (uri);
-	m->message = message;
-	camel_object_ref (message);
-	m->data = data;
-	m->done = done;
-	
-	id = m->msg.seq;
-	
-	m->driver = camel_session_get_filter_driver (session, FILTER_SOURCE_OUTGOING, NULL);
-	
-	e_thread_put (mail_thread_new, (EMsg *)m);
-	return id;
-}
-
 /* ** SEND MAIL QUEUE ***************************************************** */
 
 struct _send_queue_msg {
@@ -702,58 +624,95 @@ send_queue_send(struct _mail_msg *mm)
 {
 	struct _send_queue_msg *m = (struct _send_queue_msg *)mm;
 	CamelFolder *sent_folder = mail_component_get_folder(NULL, MAIL_COMPONENT_FOLDER_SENT);
-	GPtrArray *uids;
-	int i;
+	GPtrArray *uids, *send_uids = NULL;
+	CamelException ex;
+	int i, j;
 	
 	d(printf("sending queue\n"));
 	
-	uids = camel_folder_get_uids (m->queue);
-	if (uids == NULL || uids->len == 0)
+	if (!(uids = camel_folder_get_uids (m->queue)))
 		return;
-
-	if (m->cancel)
-		camel_operation_register (m->cancel);
-
-	for (i = 0; i < uids->len; i++) {
-		CamelMimeMessage *message;
+	
+	send_uids = g_ptr_array_sized_new (uids->len);
+	for (i = 0, j = 0; i < uids->len; i++) {
 		CamelMessageInfo *info;
-		int pc = (100 * i) / uids->len;
-		
-		report_status (m, CAMEL_FILTER_STATUS_START, pc, _("Sending message %d of %d"), i+1, uids->len);
 		
 		info = camel_folder_get_message_info (m->queue, uids->pdata[i]);
 		if (info && info->flags & CAMEL_MESSAGE_DELETED)
 			continue;
 		
-		message = camel_folder_get_message (m->queue, uids->pdata[i], &mm->ex);
-		if (camel_exception_is_set (&mm->ex))
-			break;
-		
-		mail_send_message (message, m->destination, m->driver, &mm->ex);
-		
-		if (camel_exception_is_set (&mm->ex))
-			break;
-		
-		camel_folder_set_message_flags (m->queue, uids->pdata[i], CAMEL_MESSAGE_DELETED, CAMEL_MESSAGE_DELETED);
+		send_uids->pdata[j++] = uids->pdata[i];
 	}
-
-	if (camel_exception_is_set (&mm->ex))
-		report_status (m, CAMEL_FILTER_STATUS_END, 100, _("Failed on message %d of %d"), i+1, uids->len);
+	
+	send_uids->len = j;
+	if (send_uids->len == 0) {
+		/* nothing to send */
+		camel_folder_free_uids (m->queue, uids);
+		g_ptr_array_free (send_uids, TRUE);
+		return;
+	}
+	
+	if (m->cancel)
+		camel_operation_register (m->cancel);
+	
+	camel_exception_init (&ex);
+	
+	for (i = 0, j = 0; i < send_uids->len; i++) {
+		int pc = (100 * i) / send_uids->len;
+		CamelMimeMessage *message;
+		
+		report_status (m, CAMEL_FILTER_STATUS_START, pc, _("Sending message %d of %d"), i+1, send_uids->len);
+		
+		if (!(message = camel_folder_get_message (m->queue, send_uids->pdata[i], &ex))) {
+			/* I guess ignore errors where we can't get the message (should never happen anyway)? */
+			camel_exception_clear (&ex);
+			continue;
+		}
+		
+		mail_send_message (message, m->destination, m->driver, &ex);
+		if (!camel_exception_is_set (&ex)) {
+			camel_folder_set_message_flags (m->queue, send_uids->pdata[i], CAMEL_MESSAGE_DELETED, CAMEL_MESSAGE_DELETED);
+		} else if (ex.id != CAMEL_EXCEPTION_USER_CANCEL) {
+			/* merge exceptions into one */
+			if (camel_exception_is_set (&mm->ex))
+				camel_exception_setv (&mm->ex, CAMEL_EXCEPTION_SYSTEM, "%s\n\n%s", mm->ex.desc, ex.desc);
+			else
+				camel_exception_xfer (&mm->ex, &ex);
+			camel_exception_clear (&ex);
+			
+			/* keep track of the number of failures */
+			j++;
+		} else {
+			/* transfer the USER_CANCEL exeption to the async op exception and then break */
+			camel_exception_xfer (&mm->ex, &ex);
+			break;
+		}
+	}
+	
+	j += (send_uids->len - i);
+	
+	if (j > 0)
+		report_status (m, CAMEL_FILTER_STATUS_END, 100, _("Failed to send %d of %d messages"), j, send_uids->len);
+	else if (mm->ex.id == CAMEL_EXCEPTION_USER_CANCEL)
+		report_status (m, CAMEL_FILTER_STATUS_END, 100, _("Cancelled."));
 	else
 		report_status (m, CAMEL_FILTER_STATUS_END, 100, _("Complete."));
-
+	
 	if (m->driver) {
 		camel_object_unref (m->driver);
 		m->driver = NULL;
 	}
-
-	camel_folder_free_uids (m->queue, uids);
-		
-	if (!camel_exception_is_set (&mm->ex))
-		camel_folder_expunge (m->queue, &mm->ex);
 	
-	if (sent_folder)
-		camel_folder_sync (sent_folder, FALSE, NULL);
+	camel_folder_free_uids (m->queue, uids);
+	g_ptr_array_free (send_uids, TRUE);
+	
+	camel_folder_sync (m->queue, TRUE, &ex);
+	camel_exception_clear (&ex);
+	
+	if (sent_folder) {
+		camel_folder_sync (sent_folder, FALSE, &ex);
+		camel_exception_clear (&ex);
+	}
 	
 	if (m->cancel)
 		camel_operation_unregister (m->cancel);
@@ -1047,14 +1006,14 @@ add_special_info(CamelStore *store, CamelFolderInfo *info, char *name, char *ful
 	g_return_val_if_fail (info != NULL, NULL);
 
 	parent = NULL;
-	for (fi = info; fi; fi = fi->sibling) {
+	for (fi = info; fi; fi = fi->next) {
 		if (!strcmp (fi->name, name))
 			break;
 		parent = fi;
 	}
 	
 	/* create our vTrash/vJunk URL */
-	url = camel_url_new (info->url, NULL);
+	url = camel_url_new (info->uri, NULL);
 	path = g_strdup_printf ("/%s", name);
 	if (url->fragment)
 		camel_url_set_fragment (url, path);
@@ -1069,7 +1028,7 @@ add_special_info(CamelStore *store, CamelFolderInfo *info, char *name, char *ful
 		vinfo = fi;
 		g_free (vinfo->full_name);
 		g_free (vinfo->name);
-		g_free (vinfo->url);
+		g_free (vinfo->uri);
 	} else {
 		/* There wasn't a Trash/Junk folder so create a new folder entry */
 		vinfo = g_new0 (CamelFolderInfo, 1);
@@ -1077,14 +1036,14 @@ add_special_info(CamelStore *store, CamelFolderInfo *info, char *name, char *ful
 		g_assert(parent != NULL);
 
 		/* link it into the right spot */
-		vinfo->sibling = parent->sibling;
-		parent->sibling = vinfo;
+		vinfo->next = parent->next;
+		parent->next = vinfo;
 	}
 	
 	/* Fill in the new fields */
 	vinfo->full_name = g_strdup (full_name);
 	vinfo->name = g_strdup(vinfo->full_name);
-	vinfo->url = g_strdup_printf ("%s:%s", url_base, uri);
+	vinfo->uri = g_strdup_printf ("%s:%s", url_base, uri);
 	vinfo->path = g_strdup_printf("/%s", vinfo->name);
 	g_free (uri);
 
@@ -1094,7 +1053,7 @@ add_special_info(CamelStore *store, CamelFolderInfo *info, char *name, char *ful
 static void
 add_unmatched_info(CamelFolderInfo *fi)
 {
-	for (; fi; fi = fi->sibling) {
+	for (; fi; fi = fi->next) {
 		if (!strcmp(fi->full_name, CAMEL_UNMATCHED_NAME)) {
 			g_free(fi->name);
 			fi->name = g_strdup(_("Unmatched"));
@@ -1116,13 +1075,13 @@ get_folderinfo_get (struct _mail_msg *mm)
 	
 	m->info = camel_store_get_folder_info (m->store, NULL, flags, &mm->ex);
 	if (m->info) {
-		if (m->info->url && (m->store->flags & CAMEL_STORE_VTRASH))
+		if (m->info->uri && (m->store->flags & CAMEL_STORE_VTRASH))
 			add_special_info(m->store, m->info, CAMEL_VTRASH_NAME, _("Trash"), "vtrash");
-		if (m->info->url && (m->store->flags & CAMEL_STORE_VJUNK)) {
+		if (m->info->uri && (m->store->flags & CAMEL_STORE_VJUNK)) {
 			CamelFolderInfo *info;
 
 			info = add_special_info(m->store, m->info, CAMEL_VJUNK_NAME, _("Junk"), "vjunk");
-			info->unread_message_count = -1;
+			info->unread = -1;
 		}
 
 		if (CAMEL_IS_VEE_STORE(m->store))
@@ -1876,7 +1835,9 @@ static char * get_messages_desc(struct _mail_msg *mm, int done)
 {
 	struct _get_messages_msg *m = (struct _get_messages_msg *)mm;
 
-	return g_strdup_printf(_("Retrieving %d message(s)"), m->uids->len);
+	return g_strdup_printf(ngettext("Retrieving %d message",
+					"Retrieving %d messages", m->uids->len), 
+			       m->uids->len);
 }
 
 static void get_messages_get(struct _mail_msg *mm)
@@ -1960,7 +1921,9 @@ static char *save_messages_desc(struct _mail_msg *mm, int done)
 {
 	struct _save_messages_msg *m = (struct _save_messages_msg *)mm;
 
-	return g_strdup_printf(_("Saving %d messsage(s)"), m->uids->len);
+	return g_strdup_printf(ngettext("Saving %d message", 
+					"Saving %d messsages", m->uids->len), 
+			       m->uids->len);
 }
 
 static void
@@ -2390,88 +2353,3 @@ mail_execute_shell_command (CamelFilterDriver *driver, int argc, char **argv, vo
 	
 	gnome_execute_async_fds (NULL, argc, argv, TRUE);
 }
-
-/* [Un]mark junk flag */
-
-struct _mark_junk_mail_msg {
-	struct _mail_msg msg;
-	
-	CamelFolder *folder;
-	GPtrArray *uids;
-	gboolean junk;
-};
-
-static char *
-mark_junk_describe (struct _mail_msg *mm, int complete)
-{
-	return g_strdup (_("Changing junk status"));
-}
-
-static void
-mark_junk_mark (struct _mail_msg *mm)
-{
-	struct _mark_junk_mail_msg *m = (struct _mark_junk_mail_msg *) mm;
-	CamelJunkPlugin *csp = ((CamelService *)m->folder->parent_store)->session->junk_plugin;
-	gboolean commit_reports = FALSE;
-	void (*report)(CamelJunkPlugin *, CamelMimeMessage *);
-	int i;
-
-	if (csp == NULL)
-		return;
-
-	/* FIXME: This should probably be implictly handled by the
-	   folder when you apply the junk bit, e.g. at sync time. */
-
-	if (m->junk)
-		report = camel_junk_plugin_report_junk;
-	else
-		report = camel_junk_plugin_report_notjunk;
-
-	for (i=0; i<m->uids->len; i++) {
-		CamelMimeMessage *msg = camel_folder_get_message(m->folder, m->uids->pdata[i], NULL);
-
-		if (msg) {
-			report(csp, msg);
-			commit_reports = TRUE;
-			camel_object_unref(msg);
-		}
-	}
-
-	if (commit_reports)
-		camel_junk_plugin_commit_reports(csp);
-}
-
-static void
-mark_junk_marked (struct _mail_msg *mm)
-{
-}
-
-static void
-mark_junk_free (struct _mail_msg *mm)
-{
-	struct _mark_junk_mail_msg *m = (struct _mark_junk_mail_msg *)mm;
-	
-	camel_object_unref(m->folder);
-	em_utils_uids_free(m->uids);
-}
-
-static struct _mail_msg_op mark_junk_op = {
-	mark_junk_describe,
-	mark_junk_mark,
-	mark_junk_marked,
-	mark_junk_free,
-};
-
-void
-mail_mark_junk(CamelFolder *folder, GPtrArray *uids, gboolean junk)
-{
-	struct _mark_junk_mail_msg *m;
-	
-	m = mail_msg_new(&mark_junk_op, NULL, sizeof (*m));
-	m->folder = folder;
-	camel_object_ref(folder);
-	m->uids = uids;
-	m->junk = junk;
-	
-	e_thread_put(mail_thread_queued, (EMsg *) m);
-}
