@@ -32,9 +32,11 @@
 
 #include <glib/gunicode.h>
 
-#include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 
+#include <gtk/gtkmain.h>
+#include <gtk/gtkinvisible.h>
+
 #include <gal/util/e-util.h>
 #include <gal/widgets/e-gui-utils.h>
 #include <gal/e-table/e-cell-text.h>
@@ -774,9 +776,15 @@ ml_get_save_id (ETreeModel *etm, ETreePath path, void *data)
 {
 	CamelMessageInfo *info;
 
+	if (e_tree_model_node_is_root(etm, path))
+		return g_strdup("root");
+
+	/* Note: etable can ask for the save_id while we're clearing it,
+	   which is the only time data should be null */
 	info = e_tree_memory_node_get_data (E_TREE_MEMORY(etm), path);
 	if (info == NULL)
-		return g_strdup("root");
+		return NULL;
+
 	return g_strdup (camel_message_info_uid(info));
 }
 
@@ -1844,6 +1852,7 @@ clear_info(char *key, ETreePath *node, MessageList *ml)
 
 	info = e_tree_memory_node_get_data((ETreeMemory *)ml->model, node);
 	camel_folder_free_message_info(ml->folder, info);
+	e_tree_memory_node_set_data((ETreeMemory *)ml->model, node, NULL);
 }
 
 static void
@@ -3125,7 +3134,7 @@ regen_list_regen (struct _mail_msg *mm)
 	
 	if (m->folder != m->ml->folder)
 		return;
-	
+
 	/* if we have hidedeleted on, use a search to find it out, merge with existing search if set */
 	if (!camel_folder_has_search_capability(m->folder)) {
 		/* if we have no search capability, dont let search or hide deleted work */
@@ -3287,6 +3296,9 @@ regen_list_regened (struct _mail_msg *mm)
 	if (camel_operation_cancel_check(mm->cancel))
 		return;
 
+	if (m->ml->folder != m->folder)
+		return;
+
 	if (m->dotree) {
 		save_tree_state (m->ml);
 		
@@ -3308,7 +3320,7 @@ regen_list_free (struct _mail_msg *mm)
 {
 	struct _regen_list_msg *m = (struct _regen_list_msg *)mm;
 	int i;
-	
+
 	if (m->summary) {
 		for (i = 0; i < m->summary->len; i++)
 			camel_folder_free_message_info (m->folder, m->summary->pdata[i]);
@@ -3386,7 +3398,7 @@ mail_regen_list (MessageList *ml, const char *search, const char *hideexpr, Came
 		return;
 	}
 #endif
-	
+
 	m = mail_msg_new (&regen_list_op, NULL, sizeof (*m));
 	m->ml = ml;
 	m->search = g_strdup (search);
@@ -3409,6 +3421,6 @@ mail_regen_list (MessageList *ml, const char *search, const char *hideexpr, Came
 	}
 
 	ml->regen = g_list_prepend(ml->regen, m);
-	
+
 	e_thread_put (mail_thread_new, (EMsg *)m);
 }
