@@ -27,16 +27,21 @@
 #include "e-shell-window-commands.h"
 
 #include "e-shell-about-box.h"
+#include "e-shell-importer.h"
 #include "e-shell-window.h"
 
 #include "evolution-shell-component-utils.h"
 
 #include "e-util/e-dialog-utils.h"
+#include "e-util/e-passwords.h"
 
 #include <libgnome/gnome-exec.h>
 #include <libgnome/gnome-url.h>
 #include <libgnome/gnome-i18n.h>
 
+#include <libgnomevfs/gnome-vfs-mime-handlers.h>
+#include <libgnomevfs/gnome-vfs-mime-utils.h>
+
 #include <bonobo/bonobo-ui-component.h>
 
 
@@ -74,9 +79,7 @@ command_import (BonoboUIComponent *uih,
 		EShellWindow *window,
 		const char *path)
 {
-	g_warning ("Import not implemented!");
-
-	/* e_shell_importer_start_import ();  FIXME TODO */
+	e_shell_importer_start_import (window);
 }
 
 static void
@@ -96,9 +99,7 @@ command_quit (BonoboUIComponent *uih,
 	EShell *shell = e_shell_window_peek_shell (window);
 
 	e_shell_window_save_defaults (window);
-
-	if (e_shell_prepare_for_quit (shell))
-		e_shell_close_all_windows (shell);
+	e_shell_quit(shell);
 }
 
 static void
@@ -180,6 +181,64 @@ command_help_faq (BonoboUIComponent *uih,
 	gnome_url_show ("http://www.ximian.com/apps/evolution-faq.html", NULL);	/* FIXME use the error */
 }
 
+static void
+command_quick_reference (BonoboUIComponent *uih,
+			 EShellWindow *window,
+			 const char *path)
+{
+	char *quickref;
+	char *uri;
+	char *command;
+	GString *str;
+	GnomeVFSMimeApplication *app;
+	const GList *lang_list = gnome_i18n_get_language_list ("LC_MESSAGES");
+
+	for (; lang_list != NULL; lang_list = lang_list->next) {
+		const char *lang = lang_list->data;
+
+		/* This has to be a valid language AND a language with
+		 * no encoding postfix.  The language will come up without
+		 * encoding next */
+		if (lang == NULL || strchr (lang, '.') != NULL)
+			continue;
+
+		quickref = g_build_filename (EVOLUTION_HELPDIR, "quickref", lang, "quickref.pdf", NULL);
+		if (g_file_test (quickref, G_FILE_TEST_EXISTS)) {
+			app = gnome_vfs_mime_get_default_application ("application/pdf");
+			if (app) {
+				str = g_string_new ("");
+				str = g_string_append (str, app->command);
+
+				switch (app->expects_uris) {
+				case GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS:
+					uri = g_strconcat ("file://", quickref, NULL);
+					g_string_append_printf (str, " %s", uri);
+					g_free (uri);
+					break;
+				case GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_PATHS:
+				case GNOME_VFS_MIME_APPLICATION_ARGUMENT_TYPE_URIS_FOR_NON_FILES:
+					g_string_append_printf (str, " %s", quickref);
+					break;
+				}
+
+				command = g_string_free (str, FALSE);
+				if (command != NULL &&
+				!g_spawn_command_line_async (command, NULL)) {
+					g_warning ("Could not launch %s", command);
+				}
+
+				g_free (command);
+				gnome_vfs_mime_application_free (app);
+			}
+
+			g_free (quickref);
+			return;
+		}
+
+		g_free (quickref);
+	}
+}
+
 
 static void
 command_work_offline (BonoboUIComponent *uih,
@@ -218,6 +277,13 @@ command_send_receive (BonoboUIComponent *uih,
 	e_shell_send_receive (e_shell_window_peek_shell (window));
 }
 
+static void
+command_forget_passwords (BonoboUIComponent *ui_component,
+			  void *data,
+			  const char *path)
+{
+	e_passwords_forget_passwords();
+}
 
 /* Tools menu.  */
 
@@ -257,6 +323,7 @@ static BonoboUIVerb new_verbs [] = {
 
 static BonoboUIVerb actions_verbs[] = {
 	BONOBO_UI_VERB ("SendReceive", (BonoboUIVerbFn) command_send_receive),
+	BONOBO_UI_VERB ("ForgetPasswords", command_forget_passwords),
 
 	BONOBO_UI_VERB_END
 };
@@ -270,6 +337,7 @@ static BonoboUIVerb tools_verbs[] = {
 
 static BonoboUIVerb help_verbs [] = {
 	BONOBO_UI_VERB ("HelpFAQ", (BonoboUIVerbFn) command_help_faq),
+	BONOBO_UI_VERB ("QuickReference", (BonoboUIVerbFn) command_quick_reference),
 	BONOBO_UI_VERB ("HelpSubmitBug", (BonoboUIVerbFn) command_submit_bug),
 	BONOBO_UI_VERB ("HelpAbout", (BonoboUIVerbFn) command_about_box),
 
